# Effective Operator Bases for Beyond Standard Model Scenarios: An EFT compendium for discoveries

This folder contains AutoEFT *model files* for all BSM scenarios proposed in:
<!DOCTYPE html> <html> <body> <p><b> <a href="https://inspirehep.net/literature/1813374"> Effective Operator Bases for Beyond Standard Model Scenarios: An EFT compendium for discoveries </a> </b></p>  <p><a href="https://inspirehep.net/authors/1796327">Upalaparna Banerjee</a> (<a href="https://inspirehep.net/institutions/902870">Indian Inst. Tech., Kanpur</a>), <a href="https://inspirehep.net/authors/1023458">Joydeep Chakrabortty</a> (<a href="https://inspirehep.net/institutions/902870">Indian Inst. Tech., Kanpur</a>), <a href="https://inspirehep.net/authors/1737878">Suraj Prakash</a> (<a href="https://inspirehep.net/institutions/902870">Indian Inst. Tech., Kanpur</a>), <a href="https://inspirehep.net/authors/1793542">Shakeel Ur Rahaman</a> (<a href="https://inspirehep.net/institutions/902870">Indian Inst. Tech., Kanpur</a>), <a href="https://inspirehep.net/authors/1045921">Michael Spannowsky</a> (<a href="https://inspirehep.net/institutions/908399">Durham U., IPPP</a>)</p>  <p> e-Print: <a href="https://arxiv.org/abs/2008.11512"> 2008.11512 </a>[hep-ph]</p> <p> DOI: <a href="https://doi.org/10.1007/JHEP01(2021)028"> 10.1007/JHEP01(2021)028 </a> </p> <p> Published in:<span> JHEP 01 (2021), 028</span></p> <br> </body> </html>

## Standard Model extended by uncolored particles
| model                                | file                 | no. |
|--------------------------------------|----------------------|----:|
| **SM + Singly Charged Scalar**       | [scs+sm](scs+sm.yml) | 1   |
| **SM + Doubly Charged Scalar**       | [dcs+sm](dcs+sm.yml) | 2   |
| **SM + Complex Triplet Scalar**      | [cts+sm](cts+sm.yml) | 3   |
| **SM + Left-Handed Triplet Fermion** | [ltf+sm](ltf+sm.yml) | 4   |
| **SM + Vector-like Leptons**         | [vll+sm](vll+sm.yml) | 5   |

## Standard Model extended by colored particles
| model                | file                   | no. |
|----------------------|------------------------|----:|
| **SM + Lepto-Quark** | [lqc1+sm](lqc1+sm.yml) | 1   |
| **SM + Lepto-Quark** | [lqp1+sm](lqp1+sm.yml) | 2   |

## Standard Model extended by abelian gauge symmetries
| model                                       | file                     |
|---------------------------------------------|--------------------------|
| SM extended by two abelian gauge symmetries | [u1-u1-sm](u1-u1-sm.yml) |

## BSMEFT: a few more popular scenarios
| model                              | file                   |
|------------------------------------|------------------------|
| **SM + *SU(2)* Quadruplet Scalar** | [cqs+sm](cqs+sm.yml)   |
| **SM + Lepto-Quarks**              | [lqc2+sm](lqc2+sm.yml) |
| **SM + Lepto-Quarks**              | [lqp2+sm](lqp2+sm.yml) |
